@@ -36,7 +36,7 @@ _builtins = {
     "auto": "Da",
 }
 
-_type_bad_chars = ":<>=()&"
+_type_bad_chars = ":<>=()&,"
 _type_trans = str.maketrans(_type_bad_chars, "_" * len(_type_bad_chars))
 
 
@@ -63,9 +63,14 @@ def _encode_type(param):
         names.append("P" * ptr)
 
     # actual type
-    raw_type = param["raw_type"]
+    raw_type = param.get("enum", param["raw_type"])
     typ = _builtins.get(raw_type)
     if not typ:
+        # Only mangle the typename, ignore namespaces as children might have the types
+        # aliased or something. There are cases where this would fail, but hopefully
+        # that doesn't happen?
+        # TODO: do this better
+        raw_type = raw_type.split("::")[-1]
         # assert " " not in raw_type, raw_type
         typ = "T" + raw_type.replace(" ", "").translate(_type_trans)
 
