@@ -2,7 +2,7 @@ import os
 from os.path import abspath, exists, join
 from setuptools import find_packages, setup as _setup
 from setuptools_scm import get_version
-import toml
+import tomli
 
 try:
     from wheel.bdist_wheel import bdist_wheel as _bdist_wheel
@@ -12,7 +12,6 @@ try:
             _bdist_wheel.finalize_options(self)
             self.root_is_pure = False
 
-
 except ImportError:
     bdist_wheel = None  # type: ignore
 
@@ -49,8 +48,8 @@ class Setup:
         project_fname = join(self.root, "pyproject.toml")
 
         try:
-            with open(project_fname) as fp:
-                self.pyproject = toml.load(fp)
+            with open(project_fname, "rb") as fp:
+                self.pyproject = tomli.load(fp)
         except FileNotFoundError as e:
             raise ValueError("current directory is not a robotpy-build project") from e
 
@@ -69,6 +68,24 @@ class Setup:
                 f"robotpy-build configuration in pyproject.toml is incorrect"
             ) from e
 
+        # Remove deprecated 'generate' data and migrate
+        for wname, wrapper in self.project.wrappers.items():
+            if wrapper.generate:
+                if wrapper.autogen_headers:
+                    raise ValueError(
+                        "must not specify 'generate' and 'autogen_headers'"
+                    )
+                autogen_headers = {}
+                for l in wrapper.generate:
+                    for name, header in l.items():
+                        if name in autogen_headers:
+                            raise ValueError(
+                                f"{wname}.generate: duplicate key '{name}'"
+                            )
+                        autogen_headers[name] = header
+                wrapper.autogen_headers = autogen_headers
+                wrapper.generate = None
+
     @property
     def base_package(self):
         return self.project.base_package
