@@ -1,7 +1,8 @@
 
 #pragma once
 
-// note: unnamed enums not supported at this time
+// unnamed enum at global scope not supported yet
+// enum { UGEX = 7 };
 
 // global enum
 enum GEnum { GE1 = 1 };
@@ -11,8 +12,13 @@ enum class GCEnum { GCE1 = 1 };
 
 // global enum in a namespace
 namespace enum_ns {
+
 enum NSGEnum { NSGE2 = 2 };
 enum class NSGCEnum { NSGE2 = 2 };
+
+// unnamed enum in a namespace not supported yet
+// enum { NSUGEX = 5 };
+
 } // namespace enum_ns
 
 // enum in a class
@@ -20,6 +26,9 @@ class EnumContainer {
 public:
   enum InnerEnum { IE1 = 1 };
   enum class InnerCEnum { IEC1 = 1 };
+
+  // unnamed enum in a class
+  enum { UEX = 4 };
 };
 
 // enum in a namespace in a class
@@ -30,3 +39,6 @@ public:
   enum class InnerCEnum { NSIEC1 = 1 };
 };
 }; // namespace enum_container_ns
+
+// strip prefix
+enum StripPrefixEnum { STRIP_1 = 1, STRIP_B = 2 };
\ No newline at end of file
